VERSION = "0.0.9"

STATUS_WAITING = 0; #待处理
STATUS_WORKING = 1; #进行
STATUS_CHECK_WAIT = 2; #待审核
STATUS_INSPECTOR_WAIT = 3; #待质检
STATUS_PASS = 4; #已通过
STATUS_REFUSED = 5; #已驳回
STATUS_CUSTOMER_REFUSED = 6; #客户通过
